Football Data Parser
=======================

This is a Wrapper over the data sets provided at http://www.football-data.co.uk/data.php
The aim of the project is to easily retrieve historical football data like shots on goal, scored goals etc.
from all major european football/soccer teams.

A usage example is located in the main-method.

Available data differs between leagues.
The fields that can be fetched are listed here: http://www.football-data.co.uk/notes.txt

The top-two divisions of Sweden are also parsed. Data fetched from here: http://www.stryktipsetisistastund.se/data